DVDevClientOutcome enum

What a DVDevClient.load did.

Inheritance
Available extensions

Values

applied → const DVDevClientOutcome

The bundle was applied and its pages are live.

alreadyApplied → const DVDevClientOutcome

This exact bundle is the one already applied.

unreachable → const DVDevClientOutcome

The server could not be reached (DV-DEVCLIENT-001).

unpaired → const DVDevClientOutcome

The server was reached and refused this device's token (DV-DEVCLIENT-001).

rejected → const DVDevClientOutcome

The bundle was not trusted: unsigned, sealed by another key, for another branch, older than one already loaded, or malformed.

incompatible → const DVDevClientOutcome

The bundle needs a binding this shell was not built with (DV-DEVCLIENT-002).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DVDevClientOutcome>
A constant List of the values in this enum, in order of their declaration.