DVDevClientSession class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lastStatus ↔ String?
What the last start found, for a dev menu or a log.
getter/setter pair

Static Methods

start() → Future<String>
Registers this app's VM service with the build's tunnel.

Constants

androidClass → const String
The class dartvel build android --profile development writes, in JNI's form. The CLI's tests assert it is the same string the build uses.
appleServerHostSymbol → const String
appleVmServiceSymbol → const String
The C functions dartvel build ios|macos|linux|windows --profile development writes. The CLI's tests assert they are the names the build uses.