DVSignedBundle class

A bundle whose signature has been verified.

Properties

bundle → Map<String, Object?>
The page bundle, in the OTA wire format.
final
channel → String?
final
hashCode → int
The hash code for this object.
no setterinherited
requires → DVDevClientManifest?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open(String envelope, {required List<int> publicKey, bool requireContentVersion = false}) → DVSignedBundle
Verifies envelope against publicKey and returns what it states.