DVPageBundleInstaller class
Applies page bundles delivered with a release or OTA patch.
Constructors
- DVPageBundleInstaller()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appliedVersions(
) → Future< List< String> > - Versions already applied, newest last.
-
apply(
DVPageBundle bundle) → Future< bool> -
Writes
bundle's documents into the store and records the version. -
forget(
String version) → Future< void> -
Forgets that
versionwas applied, so it can be applied again. -
isApplied(
String version) → Future< bool> -
Whether
versionhas already been applied. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited